@@ -6,7 +6,7 @@ use Test::Stream::Exporter;
 default_exports qw/is like/;
 exports qw{
     match mismatch validator
-    hash array object meta
+    hash array object meta number string
     in_set not_in_set check_set
     item field call prop check
     end filter_items
@@ -28,12 +28,14 @@ use Test::Stream::Compare::Custom;
 use Test::Stream::Compare::Event;
 use Test::Stream::Compare::Hash;
 use Test::Stream::Compare::Meta;
+use Test::Stream::Compare::Number;
 use Test::Stream::Compare::Object;
 use Test::Stream::Compare::Pattern;
 use Test::Stream::Compare::Ref;
 use Test::Stream::Compare::Regex;
 use Test::Stream::Compare::Scalar;
 use Test::Stream::Compare::Set;
+use Test::Stream::Compare::String;
 use Test::Stream::Compare::Value;
 use Test::Stream::Compare::Wildcard;
 
@@ -41,8 +43,6 @@ sub is($$;$@) {
     my ($got, $exp, $name, @diag) = @_;
     my $ctx = context();
 
-    my @caller = caller;
-
     my $delta = compare($got, $exp, \&strict_convert);
 
     if ($delta) {
@@ -60,8 +60,6 @@ sub like($$;$@) {
     my ($got, $exp, $name, @diag) = @_;
     my $ctx = context();
 
-    my @caller = caller;
-
     my $delta = compare($got, $exp, \&relaxed_convert);
 
     if ($delta) {
@@ -138,6 +136,24 @@ sub validator {
     );
 }
 
+sub number($) {
+    my @caller = caller;
+    return Test::Stream::Compare::Number->new(
+        file  => $caller[1],
+        lines => [$caller[2]],
+        input => $_[0],
+    );
+}
+
+sub string($) {
+    my @caller = caller;
+    return Test::Stream::Compare::String->new(
+        file  => $caller[1],
+        lines => [$caller[2]],
+        input => $_[0],
+    );
+}
+
 sub filter_items(&) {
     my $build = get_build() or croak "No current build!";
 
@@ -376,14 +392,15 @@ sub convert {
         if $type eq 'REGEXP';
 
     if ($type eq 'SCALAR') {
-        my $nested = relaxed_convert($$thing);
+        my $nested = convert($$thing, $strict);
         return Test::Stream::Compare::Scalar->new(item => $nested)
     }
 
     return Test::Stream::Compare::Ref->new(input => $thing)
         if $type;
 
-    return Test::Stream::Compare::Value->new(input => $thing);
+    # is() will assume string and use 'eq'
+    return Test::Stream::Compare::String->new(input => $thing);
 }
 
 1;
@@ -505,6 +522,9 @@ work as well, however there are problems if your reference contains a cyle and
 refers back to itself at some point, if this happens an exception will be
 thrown to break an otherwise infinite recursion.
 
+B<Note>: Non-reference values will be compared as strings using C<eq>, that
+means '2.0' and '2' will match.
+
 =item like($got, $expect)
 
 =item like($got, $expect, $name)
@@ -644,6 +664,14 @@ B<Note: None of these are exported by default, you need to request them.>
 
 =over 4
 
+=item $check = string "..."
+
+Verify that the value matches the given string using the C<eq> operator.
+
+=item $check = number ...;
+
+Verify that the value matches the given number using the C<==> operator.
+
 =item $check = match qr/.../
 
 Verify that the value matches the regex pattern.
